@@ -32,7 +32,7 @@ KEY_TYPES = {'str', 'int', 'float', 'bool'}
 
 PSEUDO_KEY_TYPES = {'String', 'Int', 'Float', 'Bool'}
 
-BUILTIN_FUNCTIONS = {'print', 'input', 'str', 'int', 'len', 'any', 'all', 'sum'}
+BUILTIN_FUNCTIONS = {'print', 'input', 'str', 'set', 'int', 'len', 'any', 'all', 'sum'}
 
 FORBIDDEN_TOP_LEVEL_FUNCTIONS = {'map', 'filter'}
 
@@ -411,7 +411,18 @@ class ASTTranslator:
             }
 
         elif isinstance(func, ast.Name) and func.id in BUILTIN_FUNCTIONS:
-            if func.id in ['any', 'all', 'sum']:
+            if func.id == 'set':
+                if args:
+                    raise translation_error('only set() supported', 
+                        location, self.lines[location[0]],
+                        suggestions='please use {} notation if a set has elements')
+                return {
+                    'type': 'set',
+                    'pseudo_type': ['Set', None],
+                    'elements': []
+                }
+
+            elif func.id in ['any', 'all', 'sum']:
                 if len(args) != 1:
                     raise translation_error('%s expected 1 arg, not %d' % (func.id, len(args)),
                             location, self.lines[location[0]])
@@ -471,7 +482,6 @@ class ASTTranslator:
                             }],
                             'pseudo_type': _type
                         }
-
             else:
                 arg_nodes = self._translate_node(args)
                 return self._translate_builtin_call('global', func.id, arg_nodes, location)
@@ -729,13 +739,22 @@ class ASTTranslator:
         left_node, right_node = self._translate_node(left), self._translate_node(right)
         binop_type = TYPED_API['operators'][op](left_node['pseudo_type'], right_node['pseudo_type'])[-1]
         if binop_type == 'Float' or binop_type == 'Int':
-            return {
-                'type': 'binary_op',
-                'op': op,
-                'left': left_node,
-                'right': right_node,
-                'pseudo_type': binop_type
-            }
+            if op == '**': # math:pow(left, right)
+                return {
+                    'type': 'standard_call',
+                    'namespace': 'math',
+                    'args': [left_node, right_node],
+                    'pseudo_type': binop_type,
+                    'function': 'pow'
+                }
+            else:
+                return {
+                    'type': 'binary_op',
+                    'op': op,
+                    'left': left_node,
+                    'right': right_node,
+                    'pseudo_type': binop_type
+                }
         else:
             if left_node['pseudo_type'] == 'String' and op == '%':
                 if left_node['type'] != 'string':
@@ -814,20 +833,27 @@ class ASTTranslator:
         value = operand
         if isinstance(op, ast.USub):
             value_node = self._translate_node(value)
-            if value_node.pseudo_type != 'Int' and value_node.pseudo_type != 'Float':
+            if value_node['pseudo_type'] != 'Int' and value_node['pseudo_type'] != 'Float':
                 raise type_check_error('- expects Int or Float',
                     location, self.lines[location[0]],
-                    wrong_type=value_node.pseudo_type)
-            return {
-                'type': 'unary_op',
-                'op': '-',
-                'value': value_node,
-                'pseudo_type': value_node.pseudo_type
-            }
+                    wrong_type=value_node['pseudo_type'])
+            if value_node['type'] == 'int':
+                return {
+                    'type': 'int',
+                    'value': -value_node['value'],
+                    'pseudo_type': 'Int'
+                }
+            else;
+                return {
+                    'type': 'unary_op',
+                    'op': '-',
+                    'value': value_node,
+                    'pseudo_type': value_node['pseudo_type']
+                }
         elif isinstance(op, ast.Not):
             value_node = self._testable(self._translate_node(value))
-            if value_node.type == 'standard_method_call' and value_node.message == 'present?':
-                value_node.message = 'empty?'
+            if value_node['type'] == 'standard_method_call' and value_node['message'] == 'present?':
+                value_node['message'] = 'empty?'
                 return value_node
             else:
                 return {
@@ -891,7 +917,7 @@ class ASTTranslator:
         right_node = self._translate_node(comparators[0])
         left_node = self._translate_node(left)
 
-        self._confirm_comparable(left_node['pseudo_type'], right_node['pseudo_type'], location)
+        self._confirm_comparable(op, left_node['pseudo_type'], right_node['pseudo_type'], location)
 
         result = {
             'type': 'comparison',
@@ -905,7 +931,7 @@ class ASTTranslator:
         else:
             for r in comparators[1:]:
                 left_node, right_node = right_node, self._translate_node(r)
-                self._confirm_comparable(left_node['pseudo_type'], right_node['pseudo_type'], location)
+                self._confirm_comparable(op, left_node['pseudo_type'], right_node['pseudo_type'], location)
                 result = {
                     'type': 'binary_op',
                     'op': 'and',
@@ -928,9 +954,9 @@ class ASTTranslator:
                 location, self.lines[location[0]],
                 wrong_type=index_type)
 
-    def _confirm_comparable(self, l, r, location):
-        if isinstance(l, list) or isinstance(r, list) or\
-           l != r or l not in COMPARABLE_TYPES:
+    def _confirm_comparable(self, o, l, r, location):
+        if o == '==' and l != r or o != '==' and (isinstance(l, list) or isinstance(r, list) or\
+           l != r or l not in COMPARABLE_TYPES):
             raise type_check_error(
                 '%s not comparable with %s' % (serialize_type(l), serialize_type(r)),
                 location, self.lines[location[0]],
@@ -1207,6 +1233,12 @@ class ASTTranslator:
                     'message': 'has_match',
                     'args': []
                 }
+            elif t == 'Void':
+                return {
+                    'type': 'not_null_check',
+                    'value': test_node,
+                    'pseudo_type': 'Boolean'
+                }
             else:
                 raise PseudoPythonTypeCheckError('pseudo-python expects a bool or RegexpMatch test not %s' % serialize_type(test_node['pseudo_type']))
         else:
